@@ -58,7 +58,7 @@ def ssh_copy_keys(hostname, username=None):
 
     # Get the contents of id_rsa.pub and push it to the host
     LOG.info('will connect again with password prompt')
-    distro = hosts.get(hostname, username)  # XXX Add username
+    distro = hosts.get(hostname, username, detect_sudo=False)
     auth_keys_path = '.ssh/authorized_keys'
     if not distro.conn.remote_module.path_exists(auth_keys_path):
         distro.conn.logger.warning(
@@ -189,13 +189,7 @@ def new(args):
         name=args.cluster,
         )
 
-    # FIXME: create a random key
-    LOG.debug('Creating a random mon key...')
-    mon_keyring = '[mon.]\nkey = %s\ncaps mon = allow *\n' % generate_auth_key()
-
-    keypath = '{name}.mon.keyring'.format(
-        name=args.cluster,
-        )
+    new_mon_keyring(args)
 
     LOG.debug('Writing initial config to %s...', path)
     tmp = '%s.tmp' % path
@@ -209,6 +203,15 @@ def new(args):
         else:
             raise
 
+
+def new_mon_keyring(args):
+    LOG.debug('Creating a random mon key...')
+    mon_keyring = '[mon.]\nkey = %s\ncaps mon = allow *\n' % generate_auth_key()
+
+    keypath = '{name}.mon.keyring'.format(
+        name=args.cluster,
+        )
+
     LOG.debug('Writing monitor keyring to %s...', keypath)
     tmp = '%s.tmp' % keypath
     with file(tmp, 'w') as f:
